Struct ExtImageCopyCaptureCursorSessionV1
pub struct ExtImageCopyCaptureCursorSessionV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
cursor capture session
This object represents a cursor capture session. It extends the base capture session with cursor-specific metadata.
See also the Event enum for this interface.
Implementations
impl ExtImageCopyCaptureCursorSessionV1
impl ExtImageCopyCaptureCursorSessionV1
pub fn destroy(&self)
pub fn destroy(&self)
delete this object
Destroys the session. This request can be sent at any time by the client.
This request doesn’t affect ext_image_copy_capture_frame_v1 objects created by this object.
pub fn get_capture_session<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> ExtImageCopyCaptureSessionV1
pub fn get_capture_session<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> ExtImageCopyCaptureSessionV1
get image copy capturer session
Gets the image copy capture session for this cursor session.
The session will produce frames of the cursor image. The compositor may pause the session when the cursor leaves the captured area.
This request must not be sent more than once, or else the duplicate_session protocol error is raised.